Learn R Programming

yotover (version 0.3.5)

yotov_clustered_glm: GLM Regression With Clustered Standard Errors

Description

Fits a regression with robust clustered standard errors. This uses a quasi-poisson family and returns the estimated coefficients after computing a clustered variance-covariance matrix.

Usage

yotov_clustered_glm(
  formula,
  data,
  pair = "pair_id",
  fe_pattern = "^exporter|^importer"
)

Arguments

formula

A formula for the model

data

A tibble or data.frame

pair

Inter-national fixed effects column (defaults to "pair_id")

fe_pattern

A pattern for the fixed effects variable, allows character or regex (defaults to "^exporter|^importer")