yotov_db_download: Download the Yotov database to your local computer
Description
This command downloads the Yotov trade database and populates a local
database. The download is 31.4 MB, and the database uses 3 GB on disk.
During import over 3.5 GB of disk space may be used temporarily.
Usage
yotov_db_download(
tag = NULL,
destdir = tempdir(),
cleanup = TRUE,
verbose = interactive()
)
Arguments
destdir
Where to download the compressed file.
cleanup
Whether to delete the compressed file after loading into the database.
verbose
Whether to display messages and download progress
Details
The database is stored by default under tools::R_user_dir("yotover"), or
its location can be set with the environment variable YOTOV_DB_DIR.
Examples
Run this code# NOT RUN {
yotov_db_download()
# }
Run the code above in your browser using DataLab