Learn R Programming

yotover (version 0.3.5)

yotov_model_summary2: The "Distance Puzzle" Resolved Reporting Style

Description

Computes clustered standard errors, tests on coefficients with clustered standard errors and uses the delta method to obtain changes in time-based distance estimated coefficients.

Usage

yotov_model_summary2(
  formula,
  data,
  method = "lm",
  pair = "pair_id",
  etfe = "exp_year",
  itfe = "imp_year",
  dist = "log_dist",
  intr = "log_dist_intra",
  csfe = "intra_pair"
)

Arguments

formula

A formula for the model

data

A tibble or data.frame

method

Regression method (lm or glm)

pair

Inter-national fixed effects column (defaults to "pair_id")

etfe

Exporter time fixed effects column (defaults to "exp_year")

itfe

Importer time fixed effects column (defaults to "imp_year")

dist

Distance column (defaults to "log_dist")

intr

Intra-national distance column (defaults to "log_dist_intra")

csfe

Country-specific fixed effects (defaults to "intra_pair")