Fits a regression with robust clustered standard errors. This uses a quasi-poisson family and returns the estimated coefficients after computing a clustered variance-covariance matrix.
yotov_clustered_glm(
formula,
data,
pair = "pair_id",
fe_pattern = "^exporter|^importer"
)A formula for the model
A tibble or data.frame
Inter-national fixed effects column (defaults to "pair_id")
A pattern for the fixed effects variable, allows character or regex (defaults to "^exporter|^importer")