yotov_fixed_effects: Extract fixed effects from regression object
Description
Takes an lm/glm object and extracts the fixed effects estimated coefficients.
This function was created to be used with left_join() and predict() as it
pastes the effects and allows to create a column with the predicted output.