Computes clustered standard errors, tests on coefficients with clustered standard errors and uses the delta method to obtain changes in time-based distance estimated coefficients.
yotov_model_summary2(
formula,
data,
method = "lm",
pair = "pair_id",
etfe = "exp_year",
itfe = "imp_year",
dist = "log_dist",
intr = "log_dist_intra",
csfe = "intra_pair"
)A formula for the model
A tibble or data.frame
Regression method (lm or glm)
Inter-national fixed effects column (defaults to "pair_id")
Exporter time fixed effects column (defaults to "exp_year")
Importer time fixed effects column (defaults to "imp_year")
Distance column (defaults to "log_dist")
Intra-national distance column (defaults to "log_dist_intra")
Country-specific fixed effects (defaults to "intra_pair")