yotov_status: Get the status of the current local Yotov database
Description
Get the status of the current local Yotov database. It displays informative message
about how to create the local database if it can't be found or it is corrupt.
Usage
yotov_status(verbose = TRUE)
Arguments
verbose
Whether to print a status message
Value
TRUE if the database exists, FALSE if it is not detected. (invisible)